@@ -1,6 +1,8 @@
+from django.utils.translation import gettext_lazy as _
+
 from basxbread import menu
 from basxbread.utils import Link, default_model_paths, reverse_model
-from basxbread.views import AddView, BrowseView, EditView
+from basxbread.views import AddView, DeleteView, EditView
 
 from .models import Term, Vocabulary
 from .views import TermsBrowseView, VocabularyBrowseView
@@ -15,10 +17,11 @@ urlpatterns = [
     *default_model_paths(
         Term,
         addview=AddView._with(fields=["term", "vocabulary", "slug"]),
-        editview=EditView._with(fields=["term"]),
-        browseview=TermsBrowseView._with(
-            rowclickaction=BrowseView.gen_rowclickaction("edit", return_to_current=True)
+        editview=EditView._with(
+            fields=["term", "disabled"], queryset=Term.objects.including_disabled()
         ),
+        deleteview=DeleteView._with(softdeletefield="disabled"),
+        browseview=TermsBrowseView,
     ),
 ]
 
@@ -27,7 +30,7 @@ menu.registeritem(
     menu.Item(
         Link(
             reverse_model(Vocabulary, "browse"),
-            Vocabulary._meta.verbose_name_plural,
+            label=_("Taxonomy"),
         ),
         menu.settingsgroup,
     )
